import('model.Screen')
import('model.toolbar.Toolbar')
import('model.events.CursorStackChanged')
import('model.events.InventoryChanged')

---@class Interface : Object
---@field private _player LuaPlayer
Interface = Object:extendAs("application.Interface")

---@public
---@return Interface
function Interface:new(player_index)
    local this = Interface:super(Object:new())
    this._player = game.players[player_index]
    return this
end

---@public
function Interface:createToolbar()
    Screen:new(self._player):createToolbar():centerOnScreen()
end

---@public
function Interface:deleteAll()
    for _, toolbar in ipairs(Screen:new(self._player):allChildren()) do
        toolbar:delete()
    end
end

---@public
---@param guiEvent GuiEvent
function Interface:handleGuiEvent(guiEvent)
    if guiEvent:modName() == "interface-mod" and Toolbar:containsOriginOf(guiEvent) then
        Toolbar:findUpFrom(guiEvent:element()):handleGuiEvent(guiEvent)
    end
end

---@public
---@param event Event
function Interface:handle(event)
    if event:isInstanceOf(CursorStackChanged) then
        Cursor:updateFor(self._player.index)
    elseif event:isInstanceOf(InventoryChanged) then
        Inventory:updateFor(self._player.index)
    end
    Screen:new(self._player):handle(event)
end
