require('_graphics/icons.lua')

data:extend {
    {
        order = "1",
        type = "custom-input",
        name = "interface-mod_create-toolbar",
        localised_name = "Create Toolbar",
        key_sequence = "L",
    }
}

styles = data.raw["gui-style"].default

-- BUTTONS --

styles.toolbar_button_icon_black = {
    type = "button_style",
    parent = "frame_button",
    size = 20,
    left_click_sound = { { filename = "__core__/sound/gui-click.ogg", volume = 1 } }
}

styles.toolbar_button_icon_gray = {
    type = "button_style",
    parent = "toolbar_button_icon_black",
    default_graphical_set = table.deepcopy(styles.button.default_graphical_set),
    hovered_graphical_set = table.deepcopy(styles.button.hovered_graphical_set),
    clicked_graphical_set = table.deepcopy(styles.button.clicked_graphical_set),
    disabled_graphical_set = table.deepcopy(styles.button.disabled_graphical_set),
}

styles.toolbar_button_icon_green = {
    type = "button_style",
    parent = "toolbar_button_icon_black",
    default_graphical_set = table.deepcopy(styles.green_button.default_graphical_set),
    hovered_graphical_set = table.deepcopy(styles.green_button.hovered_graphical_set),
    clicked_graphical_set = table.deepcopy(styles.green_button.clicked_graphical_set),
    disabled_graphical_set = table.deepcopy(styles.green_button.disabled_graphical_set),
}

styles.toolbar_button_icon_red = {
    type = "button_style",
    parent = "toolbar_button_icon_black",
    default_graphical_set = table.deepcopy(styles.red_button.default_graphical_set),
    hovered_graphical_set = table.deepcopy(styles.red_button.hovered_graphical_set),
    clicked_graphical_set = table.deepcopy(styles.red_button.clicked_graphical_set),
    disabled_graphical_set = table.deepcopy(styles.red_button.disabled_graphical_set),

    --left_click_sound = {{ filename = "__core__/sound/gui-red-button.ogg", volume = 0.5 }}
}

styles.toolbar_button_text_wide_gray = {
    type = "button_style",
    parent = "button",
    font = "default-small-bold",
    left_margin = 2,
    right_margin = 2,
    left_padding = 2,
    right_padding = 2,
    height = 20,
    horizontally_stretchable = "on",
    minimal_width = 80,
    maximal_width = 10000,
}

-- ELEMENTS --

styles.toolbar_space = {
    type = "empty_widget_style",
    horizontally_stretchable = "on",
    vertically_stretchable = "on",
    left_margin = 2,
    right_margin = 2,
}

styles.toolbar_drag = {
    type = "empty_widget_style",
    parent = "draggable_space",
    horizontally_stretchable = "on",
    vertically_stretchable = "on",
    left_margin = 2,
    right_margin = 2,
}

-- CONTAINERS --

styles.toolbar_container_frame = {
    type = "frame_style",
    margin = 0,
    padding = 0,
    vertical_flow_style = {
        type = "vertical_flow_style",
        parent = "toolbar_container_flow_vertical",
    },
    horizontal_flow_style = {
        type = "horizontal_flow_style",
        parent = "toolbar_container_flow_horizontal",
    },
}

styles.toolbar_container_flow_vertical = {
    type = "vertical_flow_style",
    padding = 0,
    margin = 0,
    horizontally_stretchable = "on",
    vertically_stretchable = "on",
    vertical_spacing = 0,
}

styles.toolbar_container_flow_horizontal = {
    type = "horizontal_flow_style",
    padding = 0,
    margin = 0,
    horizontally_stretchable = "on",
    vertically_stretchable = "on",
    horizontal_spacing = 0,
}

styles.toolbar_container_header = {
    type = "horizontal_flow_style",
    parent = "toolbar_container_flow_horizontal",
    padding = 0,
    horizontal_spacing = 2
}

-- STRUCTURE --

styles.toolbar = {
    type = "frame_style",
    parent = "toolbar_container_frame"
}

styles.toolbar_header = {
    type = "horizontal_flow_style",
    parent = "toolbar_container_header",
    horizontally_stretchable = "on",
    vertically_stretchable = "on",
    top_padding = 0,
    bottom_padding = 0,
}

styles.toolbar_content = {
    type = "vertical_flow_style",
    parent = "toolbar_container_flow_vertical",
}
styles.toolbar_content_addSection = {
    type = "button_style",
    parent = "toolbar_button_text_wide_gray",
    top_margin = 1 -- to do not overlap with toolbar header buttons shadows
}

styles.toolbar_content_sectionList = {
    type = "vertical_flow_style",
    parent = "toolbar_container_flow_vertical",
    vertical_spacing = 1,
}

styles.toolbar_content_sectionList_section = {
    type = "frame_style",
    parent = "toolbar_container_frame",
}

styles.toolbar_content_sectionList_section_header = {
    type = "horizontal_flow_style",
    parent = "toolbar_container_header"
}

styles.toolbar_content_sectionList_section_header_name = {
    type = "textbox_style",
    parent = "textbox",
    font = "default-small-bold",
    disabled_font_color = styles.yellow_label.font_color,
    disabled_background = {},
    left_padding = 1,
    right_padding = 1,
    height = 20,
    horizontally_stretchable = "on",
    minimal_width = 55, -- + collapse button = 2 slots, looks better when minimized with two sectionList
    maximal_width = 10000,
}

styles.toolbar_content_sectionList_section_content_table = {
    type = "frame_style",
    parent = "quick_bar_inner_panel", -- for background
    horizontal_flow_style = styles.toolbar_container_flow_horizontal,
    vertical_flow_style = styles.toolbar_container_flow_vertical,
    top_margin = 2,
    background_graphical_set = {
        position = { 208, 17 },
        corner_size = 1,
        overall_tiling_vertical_size = 26,
        overall_tiling_vertical_spacing = 14,
        overall_tiling_vertical_padding = 7,
        overall_tiling_horizontal_size = 26,
        overall_tiling_horizontal_spacing = 14,
        overall_tiling_horizontal_padding = 7,
    }
}

styles.toolbar_content_sectionList_section_content_table_row = {
    type = "horizontal_flow_style",
    parent = "toolbar_container_flow_horizontal",
}

styles.toolbar_content_sectionList_section_content_table_row_slot = {
    type = "button_style",
    parent = "quick_bar_slot_button"
}

styles.toolbar_content_sectionList_section_content_table_row_slot_selected = {
    type = "button_style",
    parent = "toolbar_content_sectionList_section_content_table_row_slot",
    default_graphical_set = styles.slot_button.selected_graphical_set,
    hovered_graphical_set = styles.slot_button.selected_hovered_graphical_set,
    clicked_graphical_set = styles.slot_button.selected_clicked_graphical_set
}
