import('model.Component')
import('model.toolbar.Toolbar')
import('model.toolbar.header.Lock')
import('model.toolbar.header.Unlock')
import('model.toolbar.header.CollapseToolbar')
import('model.toolbar.header.ExpandToolbar')
import('model.toolbar.header.DeleteToolbar')
import('model.toolbar.header.CancelDeleteToolbar')
import('model.toolbar.header.ConfirmDeleteToolbar')

---@class ToolbarHeader : Component
ToolbarHeader = Component:extendAs("model.toolbar.header.Header")

function ToolbarHeader:create(parent)
    local root = ToolbarHeader:createRoot(parent, {
        type = "flow",
        direction = "horizontal",
        style = "toolbar_header" })
    local header = ToolbarHeader:new(root)
    local toolbar = header:ancestor(Toolbar)
    root.drag_target = toolbar:root()
    Lock:create(root)
    local drag = root.add {
        type = "empty-widget",
        style = "toolbar_drag" }
    drag.drag_target = toolbar:root()

    CollapseToolbar:create(root)
    DeleteToolbar:create(root)
    return header
end

function ToolbarHeader:new(element)
    return ToolbarHeader:super(Component:new(element))
end

function ToolbarHeader:childrenClasses()
    return { Lock, Unlock,
             CollapseToolbar, ExpandToolbar,
             DeleteToolbar, CancelDeleteToolbar, ConfirmDeleteToolbar }
end

function ToolbarHeader:askForDeletion()
    self:child(DeleteToolbar):delete()
    ConfirmDeleteToolbar:create(self:root())
    CancelDeleteToolbar:create(self:root())
end

function ToolbarHeader:cancelDeletion()
    self:child(CancelDeleteToolbar):delete()
    self:child(ConfirmDeleteToolbar):delete()
    local deleteToolbar = DeleteToolbar:create(self:root())
    if self:isLocked() then
        deleteToolbar:lock()
    end
end

function ToolbarHeader:isLocked()
    return #self:children(Unlock) > 0
end
