import('model.Component')
import('model.toolbar.Toolbar')
import('model.toolbar.section.header.MoveDown')
import('model.toolbar.section.header.MoveUp')
import('model.toolbar.section.header.ExpandSection')
import('model.toolbar.section.header.CollapseSection')
import('model.toolbar.section.header.DeleteSection')
import('model.toolbar.section.header.CancelDeleteSection')
import('model.toolbar.section.header.ConfirmDeleteSection')
import('model.toolbar.section.header.SectionName')

---@class SectionHeader : Component
SectionHeader = Component:extendAs("model.toolbar.section.header.Header")

function SectionHeader:create(parent)
    local root = SectionHeader:createRoot(parent, {
        type = "flow",
        direction = "horizontal",
        style = "toolbar_content_sectionList_section_header" })
    root.style.bottom_margin = 1

    MoveDown:create(root)
    MoveUp:create(root)
    SectionName:create(root):focus()
    CollapseSection:create(root)
    DeleteSection:create(root)

    return SectionHeader:new(root)
end

function SectionHeader:new(element)
    return SectionHeader:super(Component:new(element))
end

function SectionHeader:childrenClasses()
    return {
        MoveDown, MoveUp,
        CollapseSection, ExpandSection,
        SectionName,
        DeleteSection, CancelDeleteSection, ConfirmDeleteSection }
end

---@public
function SectionHeader:askForDeletion()
    self:child(DeleteSection):delete()
    ConfirmDeleteSection:create(self:root())
    CancelDeleteSection:create(self:root())
end

---@public
function SectionHeader:cancelDeletion()
    self:child(CancelDeleteSection):delete()
    self:child(ConfirmDeleteSection):delete()
    DeleteSection:create(self:root())
end

function SectionHeader:lock()
    if self:toolbar():sectionsCount() == 1 then
        self:hide()
    end
    Component.lock(self)
end

function SectionHeader:unlock()
    self:show()
    Component.unlock(self)
end

function SectionHeader:toolbar()
    return self:ancestor(Toolbar)
end
