import('lang.Object')
import('model.Cursor')

---@class Inventory : Object
---@field private _player LuaPlayer
Inventory = Object:extendAs("model.toolbar.section.table.Inventory")
Inventory.__instances = {}

---@public
---@param player_index number
function Inventory:getInstance(player_index)
    if Inventory.__instances[player_index] == nil then
        Inventory.__instances[player_index] = Inventory:new(player_index)
    end
    return Inventory.__instances[player_index]
end

---@public
---@param player_index number
function Inventory:updateFor(player_index)
    Inventory.__instances[player_index] = nil
end

---@private
---@return Inventory
---@param player_index number
function Inventory:new(player_index)
    local this = Inventory:super(Object:new())
    this._player = game.players[player_index]
    this._content = this:content()
    return this
end

---@private
---@return table<string,number>
function Inventory:content()
    local content = {}
    self:sumTables(content, self:mainContent())
    self:sumTables(content, self:trashContent())
    return content
end

function Inventory:sumTables(table1, table2)
    for key, value in pairs(table2) do
        if table1[key] then
            table1[key] = table1[key] + value
        else
            table1[key] = value
        end
    end
end

---@private
function Inventory:mainContent()
    return self:main().get_contents()
end

---@private
function Inventory:trashContent()
    if self:hasTrash() then
        return self:trash().get_contents()
    else
        return {}
    end
end

---@public
---@param itemName string
---@return boolean
function Inventory:hasItem(itemName)
    return self:countOf(itemName) > 0
end

---@public
---@param itemName string
---@return number
function Inventory:countOf(itemName)
    return self._content[itemName] or 0
end

---@public
---@param itemName string
function Inventory:pick(itemName)
    local stack, slotIndex, inventory = self:findStack(itemName)
    local successful = Cursor:new(self._player.index):pickStack(stack)
    if successful then
        self._player.hand_location = { inventory = inventory.index, slot = slotIndex }
    end
end

---@return LuaItemStack, number, LuaInventory
function Inventory:findStack(itemName)
    local stack, slotIndex, inventory
    if self:hasTrash() and self:trash().get_item_count(itemName) > 0 then
        stack, slotIndex = self:trash().find_item_stack(itemName)
        inventory = self:trash()
    else
        stack, slotIndex = self:main().find_item_stack(itemName)
        inventory = self:main()
    end
    return stack, slotIndex, inventory
end

---@private
---@return LuaInventory
function Inventory:main()
    return self._player.get_main_inventory()
end

---@private
---@return boolean
function Inventory:hasTrash()
    return self:trash() ~= nil
end

---@private
---@return LuaInventory
function Inventory:trash()
    return self._player.get_inventory(defines.inventory.character_trash)
end
