import('model.Component')
import('model.toolbar.section.table.slots.Empty')
import('model.toolbar.section.table.slots.Item')
import('model.toolbar.section.table.slots.Tool')

---@class Row : Component
Row = Slot:extendAs("model.toolbar.section.table.Row")

function Row:create(parent)
    local root = self:createRoot(parent, {
        type = "flow",
        direction = "horizontal",
        style = "toolbar_content_sectionList_section_content_table_row" })
    return Row:new(root)
end

---@public
---@return Row
---@param element LuaGuiElement
function Row:new(element)
    return Row:super(Component:new(element))
end

function Row:childrenClasses()
    return { Empty, Item, Tool }
end

function Row:isOccupied()
    return self:lastOccupiedSlotIndex() > 0
end

---@param width number
function Row:setWidth(width)
    self:trim()
    self:pad(width)
end

---@public
function Row:trim()
    local lastOccupiedSlotIndex = math.max(1, self:lastOccupiedSlotIndex())
    for _, slotRoot in ipairs(self:slotsRoots()) do
        if slotRoot.get_index_in_parent() > lastOccupiedSlotIndex then
            slotRoot.destroy()
        end
    end
end

---@public
---@return number
function Row:lastOccupiedSlotIndex()
    local lastOccupiedSlotIndex = 0
    for _, slotRoot in ipairs(self:slotsRoots()) do
        if not Empty:is(slotRoot) then
            lastOccupiedSlotIndex = math.max(lastOccupiedSlotIndex, slotRoot.get_index_in_parent())
        end
    end
    return lastOccupiedSlotIndex
end

---@private
---@param expectedSlots number
function Row:pad(expectedSlots)
    local missingCount = expectedSlots - self:slotsCount()
    local i = 0
    while i < missingCount do
        Empty:create(self:root())
        i = i + 1
    end
end

---@private
---@return number
function Row:slotsCount()
    return #self:slotsRoots()
end

---@private
---@return LuaGuiElement[]
function Row:slotsRoots()
    return self:root().children
end
