import('lang.Object')
import('model.Component')
import('model.Cursor')
import('model.toolbar.Toolbar')
import('model.toolbar.section.table.Table')
import('model.toolbar.section.table.History')
import('model.toolbar.section.table.Inventory')

---@class Slot : Component
---@field private _player_index number
---@field private _history History
Slot = Component:extendAs("model.toolbar.section.table.Slot")

---@protected
---@return Slot
---@param element LuaGuiElement
function Slot:new(element)
    local this = Slot:super(Component:new(element))
    this._player_index = this:root().player_index
    this._history = History:getInstanceFor(this._player_index)
    return this
end

---@protected
---@param itemName string
---@return boolean
function Slot:wasDragged(itemName)
    return self._history:hasPickedSlot() and self._history:pickedSlot():isValid()
            and self._history:pickedSlot():itemName() == itemName
end

---@protected
function Slot:drag()
    self._history:pickedSlot():clear()
end

---@protected
function Slot:rememberPick()
    self._history:rememberPick(self)
end

---@protected
function Slot:forgetPick()
    self._history:forgetPick()
end

---@protected
---@param itemName string
function Slot:setItem(itemName)
    local item = Item:create(self:parent(), itemName)
    self:replaceWith(item)
    item:adjustToolbar()
end

---@protected
---@param toolName string
function Slot:setTool(toolName)
    local tool = Tool:create(self:parent(), toolName)
    self:replaceWith(tool)
    tool:adjustToolbar()
end

---@protected
function Slot:clear()
    local empty = Empty:create(self:parent())
    self:replaceWith(empty)
    empty:adjustToolbar()
end

---@private
function Slot:adjustToolbar()
    self:ancestor(Toolbar):adjustSize()
end

---@private
---@return number
function Slot:index()
    return self:root().get_index_in_parent()
end

---@protected
---@return boolean
function Slot:isOccupied()
    return self:itemName() ~= nil
end

---@protected
---@return string
function Slot:itemName()
    error("Not implemented")
end

---@protected
---@return Cursor
function Slot:cursor()
    return Cursor:getInstance(self._player_index)
end

---@protected
---@return Inventory
function Slot:inventory()
    return Inventory:getInstance(self._player_index)
end
