import('model.Component')
import('model.toolbar.section.table.Row')
import('model.toolbar.section.table.slots.Empty')

---@class Table : Component
Table = Component:extendAs("model.toolbar.section.table.Table")

function Table:create(parent)
    local root = Table:createRoot(parent, {
        type = "frame",
        direction = "vertical",
        style = "toolbar_content_sectionList_section_content_table" })
    return Table:new(root)
end

function Table:new(element)
    return Table:super(Component:new(element))
end

function Table:childrenClasses()
    return { Row }
end

---@public
---@param width number
---@param minimumHeight number
---@param heightPadding number
function Table:resize(width, minimumHeight, heightPadding)
    self:setHeight(minimumHeight, heightPadding)
    self:setWidth(width)
end

---@private
---@param minimumHeight number
---@param heightPadding number
function Table:setHeight(minimumHeight, heightPadding)
    self:trimHeight(minimumHeight)
    self:pad(minimumHeight, heightPadding)
end

---@private
function Table:trimHeight()
    local lastOccupiedRowIndex = self:lastOccupiedRowIndex()
    for _, row in ipairs(self:rows()) do
        if row:index() > lastOccupiedRowIndex then
            row:delete()
        end
    end
end

---@private
---@return number
function Table:lastOccupiedRowIndex()
    local lastOccupiedRowIndex = 0
    for _, row in ipairs(self:rows()) do
        if row:isOccupied() then
            lastOccupiedRowIndex = math.max(lastOccupiedRowIndex, row:index())
        end
    end
    return lastOccupiedRowIndex
end

---@private
---@param minimumHeight number
---@param padding number
function Table:pad(minimumHeight, padding)
    local missingRows = minimumHeight - self:height()
    local rowsToAdd = missingRows > 0 and missingRows or padding
    local i = 0
    while i < rowsToAdd do
        self:addRow()
        i = i + 1
    end
end

---@private
function Table:addRow()
    Row:create(self:root())
end

---@private
---@param width number
function Table:setWidth(width)
    for _, row in ipairs(self:rows()) do
        row:setWidth(width)
    end
end

---@public
---@return number
function Table:lastOccupiedColumnIndex()
    local rows = self:rows()
    local lastOccupiedColumnIndex = 0
    for _, row in ipairs(rows) do
        lastOccupiedColumnIndex = math.max(lastOccupiedColumnIndex, row:lastOccupiedSlotIndex())
    end
    return lastOccupiedColumnIndex
end

---@private
---@return number
function Table:height()
    return #self:root().children
end

---@private
---@return Row[]
function Table:rows()
    return self:children(Row)
end
