import('model.toolbar.section.table.Slot')
import('model.events.InventoryChanged')
import('model.events.CursorStackChanged')

---@class Item : Slot
Item = Slot:extendAs("model.toolbar.section.table.slots.Item")

function Item:create(parent, itemName)
    local element = Item:createRoot(parent, {
        type = "sprite-button",
        elem_tooltip = { type = "item", name = itemName },
        sprite = "item/" .. assert(itemName),
        style = "toolbar_content_sectionList_section_content_table_row_slot",
        mouse_button_filter = { "left", "middle" },
    })
    local item = Item:new(element)
    item:syncCount()
    return item
end

function Item:new(element)
    return Item:super(Slot:new(element))
end

---@param event Event
function Item:handle(event)
    if event:isInstanceOf(InventoryChanged) or event:isInstanceOf(CursorStackChanged) then
        self:syncCount()
    end
end

---@private
function Item:syncCount()
    local count = self:inventory():countOf(self:itemName())
    local cursor = self:cursor()
    if cursor:holdsStack() and cursor:itemName() == self:itemName() then
        count = count + cursor:stackCount()
        self:root().style = "toolbar_content_sectionList_section_content_table_row_slot_selected"
    elseif cursor:holdsGhost() and cursor:itemName() == self:itemName() then
        self:root().style = "toolbar_content_sectionList_section_content_table_row_slot_selected"
    else
        self:root().style = "toolbar_content_sectionList_section_content_table_row_slot"
    end
    self:root().number = count > 0 and count or nil
end

---@param guiEvent GuiEvent
function Item:handleGuiEvent(guiEvent)
    if guiEvent:isLeftClick() then
        local itemName = self:itemName()
        if self:inventory():hasItem(itemName) then
            self:inventory():pick(itemName)
        else
            self:cursor():pickGhost(itemName)
        end
        self:rememberPick()
    elseif guiEvent:isMiddleClick() then
        self:clear()
    end
end

function Item:itemName()
    return self:root().elem_tooltip.name
end
